@@ -140,3 +140,22 @@ def squared_padding_image(img, length=None):
                      [(margin // 2, margin - margin // 2),
                       (0, 0), (0, 0)], 'constant')
     return img
+
+
+def masks_to_bboxes(mask):
+    R, _, _ = mask.shape
+    instance_index, ys, xs = np.nonzero(mask)
+    bboxes = np.zeros((R, 4), dtype=np.float32)
+    for i in range(R):
+        ys_i = ys[instance_index == i]
+        xs_i = xs[instance_index == i]
+        if len(ys_i) == 0:
+            continue
+        y_min = ys_i.min()
+        x_min = xs_i.min()
+        y_max = ys_i.max() + 1
+        x_max = xs_i.max() + 1
+        bboxes[i] = np.array(
+            [x_min, y_min, x_max, y_max],
+            dtype=np.float32)
+    return bboxes
