@@ -1,7 +1,9 @@
 from itertools import tee
+
+
 try:
     from itertools import zip_longest
-except:
+except Exception:
     from itertools import izip_longest as zip_longest
 
 
